@@ -40,7 +40,8 @@ G_DEFINE_TYPE (DalstonPowerApplet, dalston_power_applet, G_TYPE_OBJECT)
 typedef struct _DalstonPowerAppletPrivate DalstonPowerAppletPrivate;
 
 struct _DalstonPowerAppletPrivate {
-  GtkStatusIcon *status_icon;
+  MplPanelClient *panel_client;
+
   DalstonBatteryMonitor *battery_monitor;
   DalstonBrightnessManager *brightness_manager;
 
@@ -51,8 +52,6 @@ struct _DalstonPowerAppletPrivate {
   GtkWidget *battery_secondary_label;
 
   gboolean active;
-
-  DalstonButtonMonitor *button_monitor;
 };
 
 typedef enum {
@@ -100,12 +99,30 @@ static const gchar *icon_names[] = {
 #define BATTERY_IMAGE_STATE_CHARGE_75      "dalston-power-75.png"
 #define BATTERY_IMAGE_STATE_CHARGE_100     "dalston-power-full.png"
 
+enum
+{
+  PROP_0,
+  PROP_PANEL_CLIENT,
+  PROP_BATTERY_MONITOR
+};
+
+
+static void
+dalston_power_applet_update_battery_state (DalstonPowerApplet *applet);
 
 static void
 dalston_power_applet_get_property (GObject *object, guint property_id,
                               GValue *value, GParamSpec *pspec)
 {
+  DalstonPowerAppletPrivate *priv = GET_PRIVATE (object);
+
   switch (property_id) {
+    case PROP_PANEL_CLIENT:
+      g_value_set_object (value, priv->panel_client);
+      break;
+    case PROP_BATTERY_MONITOR:
+      g_value_set_object (value, priv->battery_monitor);
+      break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
@@ -115,7 +132,15 @@ static void
 dalston_power_applet_set_property (GObject *object, guint property_id,
                               const GValue *value, GParamSpec *pspec)
 {
+  DalstonPowerAppletPrivate *priv = GET_PRIVATE (object);
+
   switch (property_id) {
+    case PROP_PANEL_CLIENT:
+      priv->panel_client = g_value_dup_object (value);
+      break;
+    case PROP_BATTERY_MONITOR:
+      priv->battery_monitor = g_value_dup_object (value);
+      break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
@@ -124,6 +149,20 @@ dalston_power_applet_set_property (GObject *object, guint property_id,
 static void
 dalston_power_applet_dispose (GObject *object)
 {
+  DalstonPowerAppletPrivate *priv = GET_PRIVATE (object);
+
+  if (priv->panel_client)
+  {
+    g_object_unref (priv->panel_client);
+    priv->panel_client = NULL;
+  }
+
+  if (priv->battery_monitor)
+  {
+    g_object_unref (priv->battery_monitor);
+    priv->battery_monitor = NULL;
+  }
+
   G_OBJECT_CLASS (dalston_power_applet_parent_class)->dispose (object);
 }
 
@@ -133,10 +172,34 @@ dalston_power_applet_finalize (GObject *object)
   G_OBJECT_CLASS (dalston_power_applet_parent_class)->finalize (object);
 }
 
+static void
+_battery_monitor_status_changed_cb (DalstonBatteryMonitor *monitor,
+                                    gpointer               userdata)
+{
+  g_debug (G_STRLOC ": Status changed");
+
+  dalston_power_applet_update_battery_state ((DalstonPowerApplet *)userdata);
+}
+
+static void
+dalston_power_applet_constructed (GObject *object)
+{
+  DalstonPowerAppletPrivate *priv = GET_PRIVATE (object);
+
+  if (G_OBJECT_CLASS (dalston_power_applet_parent_class)->constructed)
+    G_OBJECT_CLASS (dalston_power_applet_parent_class)->constructed (object);
+
+  g_signal_connect (priv->battery_monitor,
+                    "status-changed",
+                    (GCallback)_battery_monitor_status_changed_cb,
+                    object);
+}
+
 static void
 dalston_power_applet_class_init (DalstonPowerAppletClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
+  GParamSpec *pspec;
 
   g_type_class_add_private (klass, sizeof (DalstonPowerAppletPrivate));
 
@@ -144,6 +207,21 @@ dalston_power_applet_class_init (DalstonPowerAppletClass *klass)
   object_class->set_property = dalston_power_applet_set_property;
   object_class->dispose = dalston_power_applet_dispose;
   object_class->finalize = dalston_power_applet_finalize;
+  object_class->constructed = dalston_power_applet_constructed;
+
+  pspec = g_param_spec_object ("panel-client",
+                               "Panel client",
+                               "The panel client",
+                               MPL_TYPE_PANEL_CLIENT,
+                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+  g_object_class_install_property (object_class, PROP_PANEL_CLIENT, pspec);
+
+  pspec = g_param_spec_object ("battery-monitor",
+                               "Battery monitor",
+                               "The battery monitor",
+                               DALSTON_TYPE_BATTERY_MONITOR,
+                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+  g_object_class_install_property (object_class, PROP_BATTERY_MONITOR, pspec);
 }
 
 static gchar *
@@ -185,9 +263,9 @@ dalston_power_applet_format_time_remaining (guint time_remaining)
 
 typedef enum
 {
-  NOTIFICATION_30_PERCENT,
-  NOTIFICATION_15_PERCENT,
+  NOTIFICATION_20_PERCENT,
   NOTIFICATION_10_PERCENT,
+  NOTIFICATION_5_PERCENT,
   NOTIFICATION_LAST
 } NotificationLevel;
 
@@ -274,7 +352,6 @@ dalston_power_applet_update_battery_state (DalstonPowerApplet *applet)
   DalstonBatteryMonitorState state;
   gboolean ac_connected = FALSE;
   gchar *label_text;
-  BatteryIconState icon_state;
   static gint last_notification_displayed = -1;
   gchar *description;
 
@@ -289,29 +366,21 @@ dalston_power_applet_update_battery_state (DalstonPowerApplet *applet)
 
   if (ac_connected)
   {
-    icon_state = BATTERY_ICON_STATE_AC_CONNECTED;
+    mpl_panel_client_request_button_style (priv->panel_client, "state-plugged");
   } else if (percentage < 0) {
-    icon_state = BATTERY_ICON_STATE_UNKNOWN;
+    mpl_panel_client_request_button_style (priv->panel_client, "state-missing");
   } else if (percentage < 20) {
-    icon_state = BATTERY_ICON_STATE_CHARGE_0;
+    mpl_panel_client_request_button_style (priv->panel_client, "state-empty");
   } else if (percentage >= 20 && percentage < 35) {
-    icon_state = BATTERY_ICON_STATE_CHARGE_25;
-  } else if (percentage >= 35 && percentage < 60){
-    icon_state = BATTERY_ICON_STATE_CHARGE_50;
+    mpl_panel_client_request_button_style (priv->panel_client, "state-25");
+  } else if (percentage >= 35 && percentage < 60) {
+    mpl_panel_client_request_button_style (priv->panel_client, "state-50");
   } else if (percentage >= 60 && percentage < 90){
-    icon_state = BATTERY_ICON_STATE_CHARGE_75;
+    mpl_panel_client_request_button_style (priv->panel_client, "state-75");
   } else {
-    icon_state = BATTERY_ICON_STATE_CHARGE_100;
+    mpl_panel_client_request_button_style (priv->panel_client, "state-full");
   }
 
-  if (priv->active)
-  {
-    icon_state++;
-  }
-
-  gtk_status_icon_set_from_file (priv->status_icon,
-                                 icon_names[icon_state]);
-
   if (percentage < 0) {
     gtk_image_set_from_file (GTK_IMAGE(priv->battery_image),
                              PKG_ICON_DIR "/" BATTERY_IMAGE_STATE_MISSING);
@@ -365,7 +434,7 @@ dalston_power_applet_update_battery_state (DalstonPowerApplet *applet)
   if (state == DALSTON_BATTERY_MONITOR_STATE_DISCHARGING)
   {
     /* Do notifications at various levels */
-    if (percentage > 0 && percentage < 10) {
+    if (percentage > 0 && percentage < 5) {
       if (last_notification_displayed != NOTIFICATION_10_PERCENT)
       {
         dalston_power_applet_do_notification (applet, NOTIFICATION_10_PERCENT);
@@ -375,17 +444,17 @@ dalston_power_applet_update_battery_state (DalstonPowerApplet *applet)
                                _shutdown_timeout_cb,
                                applet);
       }
-    } else if (percentage < 15) {
-      if (last_notification_displayed != NOTIFICATION_15_PERCENT)
+    } else if (percentage < 10) {
+      if (last_notification_displayed != NOTIFICATION_10_PERCENT)
       {
-        dalston_power_applet_do_notification (applet, NOTIFICATION_15_PERCENT);
-        last_notification_displayed = NOTIFICATION_15_PERCENT;
+        dalston_power_applet_do_notification (applet, NOTIFICATION_10_PERCENT);
+        last_notification_displayed = NOTIFICATION_10_PERCENT;
       }
     } else if (percentage < 20) {
-      if (last_notification_displayed != NOTIFICATION_30_PERCENT)
+      if (last_notification_displayed != NOTIFICATION_20_PERCENT)
       {
-        dalston_power_applet_do_notification (applet, NOTIFICATION_30_PERCENT);
-        last_notification_displayed = NOTIFICATION_30_PERCENT;
+        dalston_power_applet_do_notification (applet, NOTIFICATION_20_PERCENT);
+        last_notification_displayed = NOTIFICATION_20_PERCENT;
       }
     } else {
       /* Reset the notification */
@@ -408,15 +477,6 @@ dalston_power_applet_update_battery_state (DalstonPowerApplet *applet)
 #endif
 }
 
-static void
-_battery_monitor_status_changed_cb (DalstonBatteryMonitor *monitor,
-                                    gpointer               userdata)
-{
-  g_debug (G_STRLOC ": Status changed");
-
-  dalston_power_applet_update_battery_state ((DalstonPowerApplet *)userdata);
-}
-
 static gboolean
 _update_on_init_idle_cb (gpointer userdata)
 {
@@ -436,32 +496,11 @@ dalston_power_applet_init (DalstonPowerApplet *self)
   GtkWidget *hbox;
   gchar *str;
 
-  /* Button monitor goes here, bleargh... */
-  priv->button_monitor = dalston_button_monitor_new ();
-
-  /* The battery monitor that will pull in the battery state */
-  priv->battery_monitor = g_object_new (DALSTON_TYPE_BATTERY_MONITOR,
-                                        NULL);
-  g_signal_connect (priv->battery_monitor,
-                    "status-changed",
-                    (GCallback)_battery_monitor_status_changed_cb,
-                    self);
-
-  /* Brightness manager. We pass this into the slider when we create it */
-  priv->brightness_manager = g_object_new (DALSTON_TYPE_BRIGHTNESS_MANAGER,
-                                           NULL);
-
-  /* The status icon that will go into the toolbar */
-  priv->status_icon = gtk_status_icon_new ();
-
-#if 0
-  gtk_status_icon_set_from_icon_name (priv->status_icon,
-                                      BATTERY_ICON_STATE_UNKNOWN);
-#endif
-
   /* Create the pane hbox */
   priv->main_hbox = gtk_hbox_new (FALSE, 4);
   gtk_container_set_border_width (GTK_CONTAINER (priv->main_hbox), 4);
+
+#if 0
   frame = nbtk_gtk_frame_new ();
   gtk_box_pack_start (GTK_BOX (priv->main_hbox),
                       frame,
@@ -486,6 +525,10 @@ dalston_power_applet_init (DalstonPowerApplet *self)
                       FALSE,
                       FALSE,
                       0);
+
+  /* Brightness manager. We pass this into the slider when we create it */
+  priv->brightness_manager = g_object_new (DALSTON_TYPE_BRIGHTNESS_MANAGER,
+                                           NULL);
   hbox = gtk_hbox_new (FALSE, 8);
   gtk_box_pack_start (GTK_BOX (vbox),
                       hbox,
@@ -513,12 +556,13 @@ dalston_power_applet_init (DalstonPowerApplet *self)
                         8);
 
   }
-  
+
+#endif
   frame = nbtk_gtk_frame_new ();
   gtk_box_pack_start (GTK_BOX (priv->main_hbox),
                       frame,
-                      FALSE,
-                      FALSE,
+                      TRUE,
+                      TRUE,
                       0);
   battery_vbox = gtk_vbox_new (FALSE, 8);
   gtk_container_set_border_width (GTK_CONTAINER (battery_vbox), 8);
@@ -562,17 +606,13 @@ dalston_power_applet_init (DalstonPowerApplet *self)
 }
 
 DalstonPowerApplet *
-dalston_power_applet_new (void)
+dalston_power_applet_new (MplPanelClient        *panel_client,
+                          DalstonBatteryMonitor *battery_monitor)
 {
-  return g_object_new (DALSTON_TYPE_POWER_APPLET, NULL);
-}
-
-GtkStatusIcon *
-dalston_power_applet_get_status_icon (DalstonPowerApplet *applet)
-{
-  DalstonPowerAppletPrivate *priv = GET_PRIVATE (applet);
-
-  return priv->status_icon;
+  return g_object_new (DALSTON_TYPE_POWER_APPLET,
+                       "panel-client", panel_client,
+                       "battery-monitor", battery_monitor,
+                       NULL);
 }
 
 GtkWidget *
@@ -591,6 +631,7 @@ dalston_power_applet_set_active (DalstonPowerApplet *applet,
 
   priv->active = active;
 
+#if 0
   if (active)
   {
     /* TODO: Update the icon to be in the active state */
@@ -598,6 +639,7 @@ dalston_power_applet_set_active (DalstonPowerApplet *applet,
   } else {
     dalston_brightness_manager_stop_monitoring (priv->brightness_manager);
   }
+#endif
 
   dalston_power_applet_update_battery_state (applet);
 }
